@@ -9,10 +9,12 @@ from enum import Enum
 class Template(Enum):
     """
     Enum of templates to be used in the app.
-    Values must match the file name in the templating/templates/ directory.
+    !!! Values must match the file name in the templating/templates/* directory !!!
     """
+    ADVANCED = 'advanced'               # Advanced template
     DEFAULT = 'default'                 # Default template multipage app
-    TABS = 'tabs'                       # Tabs template from faculty.ai
-    SIDEBAR = 'sidebar'                 # Sidebar template from faculty.ai
     IRIS = 'iris'                       # Iris K-Means Cluster - Interactively cluster the Iris dataset
-    MULTIPAGE = 'multipage'         # Multipage app template using the multipage plugin.
+    MANTINE = 'mantine'                 # Very basic mantine template
+    MULTIPAGE = 'multipage'             # Multipage app template using the multipage plugin.
+    SIDEBAR = 'sidebar'                 # Sidebar template from faculty.ai
+    TABS = 'tabs'                       # Tabs template from faculty.ai
